@@ -72,8 +72,8 @@ public:
     {
         SetWindowVariant(wxWINDOW_VARIANT_SMALL);
 #ifdef __WXOSX__
-        if (@available(macOS 11.0, *))
-            ((NSTableView*)[((NSScrollView*)GetHandle()) documentView]).style = NSTableViewStyleFullWidth;
+        ((NSTableView*)[((NSScrollView*)GetHandle()) documentView]).style = NSTableViewStyleFullWidth;
+        SetRowHeight(PX(20));
 #endif
     }
 };
@@ -109,7 +109,8 @@ MergeSummaryDialog::MergeSummaryDialog(wxWindow *parent)
     auto topsizer = new wxBoxSizer(wxVERTICAL);
     SetSizer(topsizer);
 
-    auto panel = new wxPanel(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL | MSW_OR_OTHER(wxBORDER_SIMPLE, wxBORDER_SUNKEN));
+    auto panel = new wxPanel(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL | BORDER_LISTLIKE);
+    SetupListlikeBorder(panel);
 
     ColorScheme::SetupWindowColors(panel, [=]
     {
@@ -124,7 +125,7 @@ MergeSummaryDialog::MergeSummaryDialog(wxWindow *parent)
     panel->SetSizer(sizer);
 
     m_notebook = SegmentedNotebook::Create(panel, SegmentStyle::SidebarPanels);
-    sizer->Add(m_notebook, wxSizerFlags(1).Expand().Border(wxTOP, PX(1)));
+    sizer->Add(m_notebook, wxSizerFlags(1).Expand().Border(wxTOP, PX(4)));
 
     auto buttons = CreateButtonSizer(wxOK);
     auto ok = static_cast<wxButton*>(FindWindow(wxID_OK));
@@ -167,13 +168,22 @@ void MergeSummaryDialog::TransferTo(const MergeStats& r)
         // TRANSLATORS: Column header in the list of issues where rows are filename:line:text of issue
         list->AppendTextColumn(_("Issue"), wxDATAVIEW_CELL_INERT, wxCOL_WIDTH_AUTOSIZE);
 
+        // Issues may be multiline, and variable-height row support in wxDVC leaves a lot to be desired
+        // (e.g. doesn't work with native columns, or on Mac), so we do something close enough manually.
+        int height = list->GetCharHeight();
+    
         for (auto& i: r.errors.items)
         {
+            const int lines = (int)std::count(i.text.begin(), i.text.end(), '\n') + 1;
+            const wxString firstLine = i.text.BeforeFirst('\n');
+            height = std::max(height, lines * list->GetTextExtent(firstLine).y);
+
             if (i.has_location())
                 list->AppendItem(variant_vector({i.file, wxString::Format("%d", i.line), i.text}));
             else
                 list->AppendItem(variant_vector({"", "", i.text}));
         }
+        list->SetRowHeight(height + PX(8));
     }
 
     if (!r.added.empty())
@@ -300,7 +310,7 @@ InterimResults ExtractPOTFromSourcesWithExplanatoryErrors(CatalogPtr catalog)
                     // TRANSLATORS: The System Settings etc. references macOS 13 Ventura or newer system settings and should be translated EXACTLY as in macOS. If you don't use macOS and can't check, please leave it untranslated.
                     explain += "\n\n" + _("If you previously denied access to your files, you can allow it in System Settings > Privacy & Security > Files & Folders.");
                 }
-                else if (@available(macOS 10.15, *))
+                else
                 {
                     // TRANSLATORS: The System Preferences etc. references macOS system settings and should be translated EXACTLY as in macOS. If you don't use macOS and can't check, please leave it untranslated.
                     explain += "\n\n" + _("If you previously denied access to your files, you can allow it in System Preferences > Security & Privacy > Privacy > Files & Folders.");
