@@ -74,9 +74,9 @@ public:
 #endif
 
         auto sizer = new wxBoxSizer(wxHORIZONTAL);
-        sizer->AddSpacer(PX(4));
+        sizer->AddSpacer(PX(6));
         sizer->Add(label, wxSizerFlags(1).Center().Border(wxALL, PX(2)));
-        sizer->AddSpacer(PX(4));
+        sizer->AddSpacer(PX(6));
         SetSizer(sizer);
 
         Bind(wxEVT_PAINT, [=](wxPaintEvent&)
@@ -89,7 +89,12 @@ public:
             auto rect = GetClientRect();
             if (!rect.IsEmpty())
             {
-                gc->DrawRoundedRectangle(rect.x, rect.y, rect.width, rect.height, PX(2));
+                int radius = PX(4);
+#ifdef __WXOSX__
+                if (@available(macOS 26, *))
+                    radius = rect.height / 2;
+#endif
+                gc->DrawRoundedRectangle(rect.x, rect.y, rect.width, rect.height, radius);
             }
         });
 
@@ -145,7 +150,7 @@ CrowdinLoginPanel::CrowdinLoginPanel(wxWindow *parent, int flags)
     auto loginInfoContainer = new wxBoxSizer(wxVERTICAL);
     loginInfoContainer->SetMinSize(-1, PX(50));
     loginInfoContainer->AddStretchSpacer();
-    loginInfoContainer->Add(m_loginInfo, wxSizerFlags().Center());
+    loginInfoContainer->Add(m_loginInfo, wxSizerFlags().Expand());
     loginInfoContainer->AddStretchSpacer();
 
     sizer->Add(loginInfoContainer, wxSizerFlags().Expand().ReserveSpaceEvenIfHidden().Border(wxTOP|wxBOTTOM, PX(16)));
@@ -165,7 +170,7 @@ CrowdinLoginPanel::CrowdinLoginPanel(wxWindow *parent, int flags)
     auto buttons = new wxBoxSizer(wxHORIZONTAL);
     sizer->Add(buttons, wxSizerFlags().Expand().Border(wxBOTTOM, 1));
     buttons->Add(learnMore, wxSizerFlags().Center());
-    buttons->AddSpacer(PX(60));
+    buttons->AddSpacer(PX(6));
     buttons->AddStretchSpacer();
     buttons->Add(m_signIn, wxSizerFlags());
     buttons->Add(m_signOut, wxSizerFlags());
@@ -254,8 +259,9 @@ void CrowdinLoginPanel::CreateLoginInfoControls(State state)
                       ? _(L"Waiting for authentication…")
                       : _(L"Updating user information…");
             m_activity = new ActivityIndicator(this, ActivityIndicator::Centered);
-            sizer->Add(m_activity, wxSizerFlags().Expand());
-            m_activity->Start(text);
+            sizer->Add(m_activity, wxSizerFlags(1).Center());
+            // delay so that the window is sized properly:
+            m_activity->CallAfter([=]{ m_activity->Start(text); });
             break;
         }
 
