@@ -532,8 +532,6 @@ int PoeditApp::OnExit()
 
     dispatch::cleanup();
 
-    u_cleanup();
-
     return wxApp::OnExit();
 }
 
@@ -1333,7 +1331,7 @@ void PoeditApp::OnHelp(wxCommandEvent&)
 
 void PoeditApp::OnGettextManual(wxCommandEvent&)
 {
-    wxLaunchDefaultBrowser("http://www.gnu.org/software/gettext/manual/html_node/");
+    wxLaunchDefaultBrowser("https://www.gnu.org/software/gettext/manual/html_node/");
 }
 
 
