@@ -412,7 +412,7 @@ void PoeditListCtrl::Model::GetValueByRow(wxVariant& variant, unsigned row, unsi
                 #else
                     #define MARKUP(x) x
                 #endif
-                    orig.Printf(MARKUP("<span bgcolor=\"%s\" color=\"%s\"> %s </span> %s"),
+                    orig.Printf(MARKUP("<span bgcolor=\"%s\" color=\"%s\"> %s | </span> %s"),
                         m_clrContextBg, m_clrContextFg,
                         EscapeMarkup(d->GetContext()), EscapeMarkup(orig_str));
                 }
@@ -644,8 +644,7 @@ void PoeditListCtrl::CreateColumns()
 #ifdef __WXOSX__
     NSTableView *tableView = (NSTableView*)[((NSScrollView*)GetHandle()) documentView];
     [tableView setIntercellSpacing:NSMakeSize(3.0, 0.0)];
-    if (@available(macOS 11.0, *))
-        tableView.style = NSTableViewStyleFullWidth;
+    tableView.style = NSTableViewStyleFullWidth;
 #endif
 
     m_colID = m_colIcon = m_colSource = m_colTrans = nullptr;
@@ -793,9 +792,7 @@ void PoeditListCtrl::SizeColumns()
             if (!GetColumn(c)->IsHidden())
                 visibleCols++;
         }
-        w -= 3 * visibleCols;
-        if (@available(macOS 11.0, *))
-            w -= 9;
+        w -= 9 + 3 * visibleCols;
     }
 #elif defined(__WXGTK__)
     w -= 2;
