@@ -48,7 +48,7 @@
 namespace
 {
 
-#define GETTEXT_VERSION_NUM(x, y, z)  ((x*1000*1000) + (y*1000) + (z))
+#define GETTEXT_VERSION_NUM(x, y, z)  ((uint32_t)(((x)*100*100) + ((y)*100) + (z)))
 
 // Determine gettext version, return it in the form of XXXYYYZZZ number for version x.y.z
 uint32_t gettext_version()
@@ -69,6 +69,7 @@ uint32_t gettext_version()
                 const int y = std::stoi(m.str(3));
                 const int z = m[5].matched ? std::stoi(m.str(5)) : 0;
                 s_version = GETTEXT_VERSION_NUM(x, y, z);
+                wxLogTrace("poedit", "detected GNU gettext version %d.%d.%d (%06d)", x, y, z, (int)s_version);
             }
         }
     }
@@ -137,6 +138,12 @@ void log_errors_with_filter(const ParsedGettextErrors& errors, Functor&& filter)
 } // anonymous namespace
 
 
+bool check_gettext_version(int major, int minor, int patch)
+{
+    return gettext_version() >= GETTEXT_VERSION_NUM(major, minor, patch);
+}
+
+
 wxString ParsedGettextErrors::Item::pretty_print() const
 {
     wxString prefix;
@@ -166,29 +173,34 @@ ParsedGettextErrors parse_gettext_stderr(const subprocess::Output& output, const
 
     struct StdPrefixEater
     {
-        StdPrefixEater()
-            : m_prefixWarning(str::to_wstring(wxGetTranslation("warning: ", "gettext-tools"))),
-              m_prefixError(str::to_wstring(wxGetTranslation("error: ", "gettext-tools")))
+        StdPrefixEater(const std::wstring& warning, const std::wstring& error)
+            : m_prefixWarning(warning), m_prefixError(error)
         {}
 
-        inline void eat_std_prefixes(std::wstring& err, ParsedGettextErrors::Item& rec)
+        inline bool eat_std_prefixes(std::wstring& err, ParsedGettextErrors::Item& rec)
         {
             if (boost::starts_with(err, m_prefixError))
             {
                 err = err.substr(m_prefixError.length());
                 // this is the default already, but let's be explicit:
                 rec.level = ParsedGettextErrors::Error;
+                return true;
             }
             else if (boost::starts_with(err, m_prefixWarning))
             {
                 err = err.substr(m_prefixWarning.length());
                 rec.level = ParsedGettextErrors::Warning;
+                return true;
             }
+            return false;
         }
 
         std::wstring m_prefixWarning, m_prefixError;
     };
-    StdPrefixEater eater;
+
+    StdPrefixEater eaterEnglish(L"warning: ", L"error: ");
+    StdPrefixEater eaterLocalized(str::to_wstring(wxGetTranslation("warning: ", "gettext-tools")),
+                                  str::to_wstring(wxGetTranslation("error: ", "gettext-tools")));
 
     process_error_output
     (
@@ -201,7 +213,8 @@ ParsedGettextErrors parse_gettext_stderr(const subprocess::Output& output, const
             ParsedGettextErrors::Item rec;
 
             // recognizing standard prefixes first simplifies differentiating between then and file:line locations:
-            eater.eat_std_prefixes(err, rec);
+            if (!eaterLocalized.eat_std_prefixes(err, rec))
+                eaterEnglish.eat_std_prefixes(err, rec);
 
             static const std::wregex RE_LOCATION(L"^([^\r\n]+):([0-9]+): ", std::regex_constants::ECMAScript | std::regex_constants::optimize);
             std::wsmatch match;
@@ -213,7 +226,8 @@ ParsedGettextErrors parse_gettext_stderr(const subprocess::Output& output, const
             }
 
             // have to do again, as the standard format is e.g. "test.c:7: warning: text..."
-            eater.eat_std_prefixes(err, rec);
+            if (!eaterLocalized.eat_std_prefixes(err, rec))
+                eaterEnglish.eat_std_prefixes(err, rec);
 
             rec.text = err;
 
@@ -301,7 +315,7 @@ void GettextRunner::preprocess_args(subprocess::Arguments& args) const
 
     // gettext 0.22 started converting MO files to UTF-8 by default. Don't do that.
     // See https://git.savannah.gnu.org/gitweb/?p=gettext.git;a=commit;h=5412a4f79929004cb6db15d545e07dc953330e8d
-    if (args.program() == L"msgfmt" && gettext_version() >= GETTEXT_VERSION_NUM(0, 22, 0))
+    if (args.program() == L"msgfmt" && check_gettext_version(0, 22))
     {
         args.insert(1, L"--no-convert");
     }
