@@ -34,6 +34,8 @@
 
 #if wxUSE_GUI
     #include <wx/toplevel.h>
+    #include "hidpi.h"
+    #include "colorscheme.h"
 #endif
 
 
@@ -41,6 +43,8 @@
 // Misc platform differences
 // ----------------------------------------------------------------------
 
+#if wxUSE_GUI
+
 #ifdef __WXMSW__
     #define MSW_OR_OTHER(msw, other) msw
 #else
@@ -62,17 +66,35 @@
 #endif
 
 #ifdef __WXOSX__
-    inline int AboveChoicePadding()
+    #define BORDER_LIST         wxBORDER_DEFAULT
+    #define BORDER_LISTLIKE     wxBORDER_NONE
+    #ifdef __OBJC__
+    inline void SetupListlikeBorder(wxWindow *w)
     {
-        if (__builtin_available(macOS 11.0, *))
-            return 2;
-        else
-            return 0;
+        ColorScheme::SetupWindowColors(w, [=]
+        {
+            NSView *view = (NSView*)w->GetHandle();
+            [view.effectiveAppearance performAsCurrentDrawingAppearance: [&]{
+                view.wantsLayer = YES;
+                view.layer.borderColor = NSColor.separatorColor.CGColor;
+                view.layer.borderWidth = 1.0;
+            }];
+        });
     }
+    #endif
 #else
-    #define AboveChoicePadding()  0
+    #ifdef __WXMSW__
+        #define BORDER_LIST     wxBORDER_THEME
+        #define BORDER_LISTLIKE wxBORDER_SIMPLE
+    #else
+        #define BORDER_LIST     wxBORDER_SUNKEN
+        #define BORDER_LISTLIKE wxBORDER_SUNKEN
+    #endif
+    inline void SetupListlikeBorder(wxWindow*) {}
 #endif
 
+#endif // wxUSE_GUI
+
 
 // ----------------------------------------------------------------------
 // Misc helpers
